# from mh_package import Module1
from mh_package import Birds

def joke():
    print ("in joke....0.13")
    return (u'my mh_package version 0.13.')

if __name__ == '__main__':
    print ('hello world...')
    joke()
    # Module1.foo1()
    myBird = Birds.Birds()
    myBird.printMembers()




from setuptools import setup

setup(name='mh_package',
      version='0.13',
      description='My mh_package version',
      url='https://job4moshe@dev.azure.com/job4moshe/mh_package/_git/mh_package',
      author='Moshe Hayoun',
      author_email='job4moshe@gmail.com',
      license='MIT',
      packages=['mh_package'],
      zip_safe=False)
